apply_residual_into

Function apply_residual_into 

pub fn apply_residual_into(
    values: &mut [f32],
    residual: &[u8],
) -> Result<(), CodecError>
Decode a residual byte-slice as f16 LE values and add them in place into values.

Returns CodecError::LengthMismatch if residual.len() != values.len() * 2.

Errors

Returns CodecError::LengthMismatch when the residual buffer has the wrong length.