VectorEntry entity — one compressed vector stored in a Corpus.
VectorEntry
Corpus
Identity is determined solely by VectorId; equality and hashing ignore the compressed payload and metadata. This matches Python’s behaviour where dict keys are the vector identifiers.
VectorId
dict